@@ -37,7 +37,7 @@ by creating an instance of PersistentDB, passing the following parameters:
 		prepare the session, e.g. ["set datestyle to german", ...].
 
 	Additionally, you have to pass the parameters for the actual
-	databse connection which are passed via the DB-API 2 module,
+	database connection which are passed via the DB-API 2 module,
 	such as the names of the host, database, user, password etc.
 
 For instance, if you are using pgdb as your DB-API 2 database module and want
@@ -56,40 +56,39 @@ You can use these connections just as if they were ordinary
 DB-API 2 connections. Actually what you get is the hardened
 SolidDB version of the underlying DB-API 2 connection.
 
-You should not use db.close() since this would really close the
-connection and reopen it at the next usage anyway. This would
-be contrary to the intent of having persistent connections.
+Closing a persistent connection with db.close() will be silently
+ignored since it would be reopened at the next usage anyway and
+contrary to the intent of having persistent connections. Instead,
+the connection will be automatically closed when the thread dies.
+You can change this behavior be setting persist._closeable to True.
 
 
 Requirements:
 
-Python 2.4.1 recommended. Minimum requirement: Python 2.2.
+Minimum requirement: Python 2.2. Recommended: Python 2.4.3.
 
 
 Ideas for improvement:
 
 * Add thread for monitoring and restarting bad or expired connections
-(similar to DBConnectionPool/ResourcePool by Warren Smith).
+  (similar to DBConnectionPool/ResourcePool by Warren Smith).
 * Optionally log usage, bad connections and exceeding of limits.
 
 
-Copyright and credit info:
+Copyright, credits and license:
 
 * Contributed as supplement for Webware for Python and PyGreSQL
-by Christoph Zwerschke in September 2005
+  by Christoph Zwerschke in September 2005
 * Based on an idea presented on the Webware developer mailing list
-by Geoffrey Talvola in July 2005
+  by Geoffrey Talvola in July 2005
 
-
-License and disclaimer:
-
-See http://www.webwareforpython.org/Webware/Docs/Copyright.html
+Licensed under the Open Software License version 2.1.
 
 """
 
-__version__ = '0.8.1'
-__revision__ = "$Rev: 3097 $"
-__date__ = "$Date: 2005-09-12 21:11:06 +0200 (Mo, 12 Sep 2005) $"
+__version__ = '0.9.1'
+__revision__ = "$Rev: 5229 $"
+__date__ = "$Date: 2006-05-08 13:40:11 +0200 (Mo, 08 Mai 2006) $"
 
 
 from SolidDB import connect
@@ -103,6 +102,7 @@ class PersistentDB:
 
 	After you have created the connection pool, you can use
 	connection() to get thread-affine, solid DB-API 2 connections.
+
 	"""
 
 	def __init__(self, dbapi,
@@ -117,6 +117,10 @@ class PersistentDB:
 			the session, e.g. ["set datestyle to ...", "set time zone ..."]
 		args, kwargs: the parameters that shall be used to establish
 			the database connections using the DB-API 2 module
+
+		Set the _closeable attribute to True or 1 to allow closing
+		connections. By default, this will be silently ignored.
+
 		"""
 		if not getattr(dbapi, 'threadsafety', None):
 			raise NotSupportedError, "Database module is not thread-safe."
@@ -124,6 +128,7 @@ class PersistentDB:
 		self._maxusage = maxusage
 		self._setsession = setsession
 		self._args, self._kwargs = args, kwargs
+		self._closeable = 0
 		self.thread = local()
 
 	def solid_connection(self):
@@ -137,9 +142,11 @@ class PersistentDB:
 		The shareable parameter exists only for compatibility with the
 		PooledDB connection method. In reality, persistent connections
 		are of course never shared with other threads.
+
 		"""
 		if not hasattr(self.thread, 'connection'):
 			self.thread.connection = self.solid_connection()
+			self.thread.connection._closeable = self._closeable
 		return self.thread.connection
 
 
