@@ -56,8 +56,8 @@ For instance, if you are using pgdb as your DB-API 2 database module and
 want a pool of at least five connections to your local database 'mydb':
 
 	import pgdb # import used DB-API 2 module
-	from PooledPg import PooledPg
-	pool = PooledPg(5, database='mydb')
+	from PooledDB import PooledDB
+	pool = PooledPg(pgdb, 5, database='mydb')
 
 Once you have set up the connection pool you can request
 database connections from that pool:
@@ -77,31 +77,43 @@ module allows this. If you want to have a dedicated connection, use:
 If you don't need it any more, you should immediately return it to the
 pool with db.close(). You can get another connection in the same way.
 
+Warning: In a threaded environment, never do the following:
+
+	pool.connection().cursor().execute(...)
+
+This would release the connection too early for reuse which may be
+fatal if the connections are not thread-safe. Make sure that the
+connection object stays alive as long as you are using it, like that:
+
+	db = pool.connection()
+	cur = db.cursor()
+	cur.execute(...)
+	res = cur.fetchone()
+	cur.close() # or del cur
+	db.close() # or del db
+
 
 Ideas for improvement:
 
 * Add thread for monitoring and restarting bad or expired connections
-(similar to DBConnectionPool/ResourcePool by Warren Smith).
+  (similar to DBConnectionPool/ResourcePool by Warren Smith).
 * Optionally log usage, bad connections and exceeding of limits.
 
 
-Copyright and credit info:
+Copyright, credits and license:
 
 * Contributed as supplement for Webware for Python and PyGreSQL
-by Christoph Zwerschke in September 2005
+  by Christoph Zwerschke in September 2005
 * Based on the code of DBPool, contributed to Webware for Python
-by Dan Green in December 2000
+  by Dan Green in December 2000
 
-
-License and disclaimer:
-
-See http://www.webwareforpython.org/Webware/Docs/Copyright.html
+Licensed under the Open Software License version 2.1.
 
 """
 
-__version__ = '0.8.1'
-__revision__ = "$Rev: 3097 $"
-__date__ = "$Date: 2005-09-12 21:11:06 +0200 (Mo, 12 Sep 2005) $"
+__version__ = '0.9.1'
+__revision__ = "$Rev: 5229 $"
+__date__ = "$Date: 2006-05-08 13:40:11 +0200 (Mo, 08 Mai 2006) $"
 
 
 from SolidDB import connect
@@ -118,6 +130,7 @@ class PooledDB:
 
 	After you have created the connection pool, you can use
 	connection() to get pooled, solid PostGreSQL connections.
+
 	"""
 
 	def __init__(self, dbapi,
@@ -149,6 +162,7 @@ class PooledDB:
 			the session, e.g. ["set datestyle to ...", "set time zone ..."]
 		args, kwargs: the parameters that shall be used to establish
 			the PostgreSQL connections using class PyGreSQL pg.DB()
+
 		"""
 		self._dbapi = dbapi
 		# Connections can be only shareable if the underlying DB-API 2
@@ -198,6 +212,7 @@ class PooledDB:
 
 		If shareable is set and the underlying DB-API 2 allows it,
 		then the connection may be shared with other threads.
+
 		"""
 		if shareable and self._maxshared:
 			self._condition.acquire()
@@ -307,6 +322,7 @@ class PooledDedicatedDBConnection:
 
 		pool: the corresponding PooledDB instance
 		con: the underlying SolidDB connection
+
 		"""
 		self._pool = pool
 		self._con = con
@@ -337,6 +353,7 @@ class SharedDBConnection:
 		"""Create a shared connection.
 
 		con: the underlying SolidDB connection
+
 		"""
 		self.con = con
 		self.shared = 1
@@ -361,6 +378,7 @@ class PooledSharedDBConnection:
 
 		pool: the corresponding PooledDB instance
 		con: the underlying SharedDBConnection
+
 		"""
 		self._pool = pool
 		self._shared_con = shared_con
