@@ -67,31 +67,40 @@ The connection will not be shared with other threads. If you don't need
 it any more, you should immediately return it to the pool with db.close().
 You can get another connection in the same way or with db.reopen().
 
+Warning: In a threaded environment, never do the following:
+
+	res = pool.connection().query(...).getresult()
+
+This would release the connection too early for reuse which may be
+fatal because the connections are not thread-safe. Make sure that the
+connection object stays alive as long as you are using it, like that:
+
+	db = pool.connection()
+	res = db.query(...).getresult()
+	db.close() # or del db
+
 
 Ideas for improvement:
 
 * Add thread for monitoring and restarting bad or expired connections
-(similar to DBConnectionPool/ResourcePool by Warren Smith).
+  (similar to DBConnectionPool/ResourcePool by Warren Smith).
 * Optionally log usage, bad connections and exceeding of limits.
 
 
-Copyright and credit info:
+Copyright, credits and license:
 
 * Contributed as supplement for Webware for Python and PyGreSQL
-by Christoph Zwerschke in September 2005
+  by Christoph Zwerschke in September 2005
 * Based on the code of DBPool, contributed to Webware for Python
-by Dan Green in December 2000
+  by Dan Green in December 2000
 
-
-License and disclaimer:
-
-See http://www.webwareforpython.org/Webware/Docs/Copyright.html
+Licensed under the Open Software License version 2.1.
 
 """
 
-__version__ = '0.8.1'
-__revision__ = "$Rev: 3097 $"
-__date__ = "$Date: 2005-09-12 21:11:06 +0200 (Mo, 12 Sep 2005) $"
+__version__ = '0.9.1'
+__revision__ = "$Rev: 5229 $"
+__date__ = "$Date: 2006-05-08 13:40:11 +0200 (Mo, 08 Mai 2006) $"
 
 
 from SolidPg import SolidPgConnection
@@ -107,6 +116,7 @@ class PooledPg:
 
 	After you have created the connection pool, you can use
 	connection() to get pooled, solid PostGreSQL connections.
+
 	"""
 
 	def __init__(self,
@@ -133,6 +143,7 @@ class PooledPg:
 			the session, e.g. ["set datestyle to ...", "set time zone ..."]
 		args, kwargs: the parameters that shall be used to establish
 			the PostgreSQL connections using class PyGreSQL pg.DB()
+
 		"""
 		self._args, self._kwargs = args, kwargs
 		self._maxusage = maxusage
@@ -203,6 +214,7 @@ class PooledPgConnection:
 
 		pool: the corresponding PooledPg instance
 		con: the underlying SolidPg connection
+
 		"""
 		self._pool = pool
 		self._con = con
